// The program opens a connection to an instrument and queries its identification string
// with a SCPI command '*IDN?'

// Preconditions:
// - R&S VISA or NI VISA or installed
// - Resource string adjusted to fit your instrument physical connection

#include <userint.h>
#include <ansi_c.h>
#include <visa.h>
#include <cvirte.h>

int main (void)
{
        char idnQuery[] = "*IDN?\n";    
        ViStatus status = VI_SUCCESS;
        
        ViUInt32 returnCount = 0;
        ViSession rmHandle, scopeHandle;
        char idnResponse[1024];
        char message[1024];
        
        // Standard LAN connection (also called VXI-11)
        char resourceString1[] = "TCPIP::192.168.1.101::INSTR"; 
        // Hi-Speed LAN connection - see 1MA208
        char resourceString2[] = "TCPIP::192.168.1.101::hislip0"; 
        // GPIB Connection
        char resourceString3[] = "GPIB::20::INSTR"; 
        // USB-TMC (Test and Measurement Class)
        char resourceString4[] = "USB::0x0AAD::0x0119::022019943::INSTR";
        
        // Open Resource manager first
        status = viOpenDefaultRM (&rmHandle);

        status = viOpen(rmHandle, resourceString1, VI_NULL, VI_NULL, &scopeHandle);
        status = viClear(scopeHandle); //clear instrument's io buffers

        status = viWrite(scopeHandle, (ViBuf)idnQuery, (ViUInt32)strlen(idnQuery), VI_NULL);
        status = viRead(scopeHandle, (ViBuf)idnResponse, 1024, &returnCount);
        idnResponse[returnCount] = 0; //terminate the string properly
        
        sprintf (message, "Hello, I am\n%s", idnResponse);
        MessagePopup ("Hello World", message);
        
    return 0;
}


